A biblioteca calcula (atualmente) o valor de PI e do Numero de Euler ||
Calcula Funções: Seno, Cosseno ||
fatora um numero || 
calcula o fatorial de um numero || 
o modulo || 
gera um numero aleatorio entre 2 numeros || 
calcula raizes cubicas e quadrada e calcula as raizes de equações de primeiro e segundo grau

Feito por **Gabriel Lima**
